@@ -83,8 +83,15 @@ process_single_count_target <- function(x) {
         process_count_distinct_total_row(current_env())
       }
 
-      if(!total_denom_ignore && !is.null(total_count_format) && !(is.null(denom_ignore) || length(denom_ignore) == 0) &&
-         ("pct" %in% total_count_format$vars || "distinct_pct" %in% total_count_format$vars)) {
+      # Used to temporarily check formats
+      if(is.null(format_strings)) tmp_fmt <- gather_defaults.count_layer(current_env())
+      if(count_missings && !(is.null(denom_ignore) || length(denom_ignore) == 0) &&
+         (("pct" %in% total_count_format$vars || "distinct_pct" %in% total_count_format$vars) ||
+         # Logic if no total_count format
+         (is.null(total_count_format) && is.null(format_strings) && ("pct" %in% tmp_fmt$n_counts$vars || "distinct_pct" %in% tmp_fmt$n_counts$vars)) ||
+         (is.null(total_count_format) && ("pct" %in% count_fmt$n_counts$vars || "distinct_pct" %in% count_fmt$n_counts$vars))
+         )
+         ) {
            warning("Your total row is ignoring certain values. The 'pct' in this row may not be 100%",
                    immediate. = TRUE)
          }
@@ -304,8 +311,8 @@ change this behavior, use `set_denoms_by()`.", immediate. = TRUE)
     }, treat_var, cols)
 
     #Create an expression to evaluate filter
-    if(total_denom_ignore){
-      filter_logic <- expr(!(!!target_var[[1]] %in% unlist(denom_ignore)))
+    if(!count_missings){
+      filter_logic <- expr(!(!!target_var[[1]] %in% names(missing_count_list)))
     } else {
       filter_logic <- expr(TRUE)
     }
@@ -354,8 +361,8 @@ change this behavior, use `set_denoms_by()`.", immediate. = TRUE)
     }, treat_var, cols)
 
     #Create an expression to evaluate filter
-    if(total_denom_ignore){
-      filter_logic <- expr(!(!!target_var[[1]] %in% unlist(denom_ignore)))
+    if(!count_missings){
+      filter_logic <- expr(!(!!target_var[[1]] %in% names(missing_count_list)))
     } else {
       filter_logic <- expr(TRUE)
     }
@@ -395,6 +402,7 @@ prepare_format_metadata.count_layer <- function(x) {
       format_strings[['n_counts']] <- gather_defaults(environment())[['n_counts']]
     }
 
+
     # If there is both n & distinct, or pct and distinct_pct there has to be a
     # distinct_by
     # If both distinct and n
@@ -462,7 +470,8 @@ process_formatting.count_layer <- function(x, ...) {
                                summary_var = summary_var,
                                indentation_length = indentation_length,
                                total_count_format = total_count_format,
-                               total_row_label = total_row_label)
+                               total_row_label = total_row_label,
+                               has_missing_count = has_missing_count)
       }) %>%
       # Pivot table
         pivot_wider(id_cols = c(match_exact(by), "summary_var"),
@@ -530,7 +539,7 @@ process_formatting.count_layer <- function(x, ...) {
 construct_count_string <- function(.n, .total, .distinct_n = NULL, .distinct_total = NULL,
                                    count_fmt = NULL, max_layer_length, max_n_width, missing_string,
                                    missing_f_str, summary_var, indentation_length, total_count_format,
-                                   total_row_label) {
+                                   total_row_label, has_missing_count) {
 
   ## Added this for processing formatting in nested count layers where this won't be processed yet
   if (is.null(max_layer_length)) max_layer_length <- 0
@@ -538,6 +547,11 @@ construct_count_string <- function(.n, .total, .distinct_n = NULL, .distinct_tot
   missing_rows <- FALSE
   total_rows <- FALSE
 
+  # Add in the missing format if its null and there are missing counts
+  if(has_missing_count && is.null(missing_f_str)) {
+    missing_f_str <- count_fmt
+  }
+
   if (!is.null(missing_f_str)) {
 
     # This subsets the indentation length for nested count layers. The 'outer'
